Unified protocol server lifecycle implementation Unified protocol server implementation for the GraphQL mock server.
Structs
- Graphql
Mock Server - A
MockProtocolServerwrapper around the GraphQL server startup.
Unified protocol server lifecycle implementation Unified protocol server implementation for the GraphQL mock server.
MockProtocolServer wrapper around the GraphQL server startup.